@@ -83,7 +83,7 @@ class SendGrid(object):
     def call(self, api, resource, params=None):
         url = self.build_url(api, resource)
         call_params = self.build_params(params or {})
-        response = requests.post(url, data=call_params, timeout=60)
+        response = requests.post(url, params=call_params)
         try:
             response_content = json.loads(response.content)
         except ValueError:
